Learn R Programming

shinyga (version 0.1.2.9001)

shinygaGetCustomMetrics: Get GA customMetrics

Description

Gets the Custom Metrics available for each web property.

Usage

shinygaGetCustomMetrics(token, accountId, webPropertyId, start = 1, max = 1000)

Arguments

token
Token passed from shinygaGetToken()
accountId
AccountId of webproperty
webPropertyId
webPropertyId
max
Maximum number to fetch

Value

If token exists, a dataframe of filters for the account.

See Also

Other fetch data functions: MEgetData; getAndMergeGAAccounts; processManagementData; rollupGA; shinygaGetAccounts; shinygaGetAdWords; shinygaGetCustomDataSources; shinygaGetCustomDimensions; shinygaGetFilters; shinygaGetGoals; shinygaGetProfiles; shinygaGetSegments; shinygaGetUsers; shinygaGetWebProperties

Examples

Run this code
## Not run: 
# metrics <- shinygaGetCustomMetrics(123456)
# ## End(Not run)

Run the code above in your browser using DataLab