Learn R Programming

shinyga (version 0.1.2.9001)

shinygaGetToken: Returns the authentication Token

Description

Once a user browses to ShinyGetTokenURL and is redirected back with request shinygaGetToken takes that code and returns a token needed for Google APIs Uses the same client.id and client.secret as ShinyGetTokenURL

Usage

shinygaGetToken(code, client.id = CLIENT_ID, client.secret = CLIENT_SECRET, redirect.uri = CLIENT_URL)

Arguments

code
The code passed from AuthCode().
client.id
The client ID taken from the Google API Console.
client.secret
The client secret taken from the Google API Console.
redirect.uri
The URL of where your Shiny application sits, that will read state parameter.

Value

The token from Google that authenticates future API calls.

See Also

Shortcut using doAuthMacro.

Other authentication functions: authReturnCode; createCode; doAuthMacro; shinygaGetTokenURL

Examples

Run this code
## Not run: 
# securityCode <- createCode()
# shinyServer(function(input, output, session)){
# 
#   AuthCode <- reactive({
# 
#       authReturnCode(session, securityCode)
# 
#   })
# 
#   output$AuthGAURL <- renderUI({
# 
#        a("Click Here to Authorise Your Google Analytics Access",
#           href=ShinyGetTokenURL(securityCode)
#           )
#        })
# 
#   AccessToken <- reactive({
#       validate(
#         need(AuthCode(), "Authenticate To See")
#       )
# 
#       access_token <- ShinyGetToken(code = AuthCode())
# 
#       token <- access_token$access_token
# 
#     })
# }
# ## End(Not run)

Run the code above in your browser using DataLab