Learn R Programming

shinyga (version 0.1.2.9001)

shinygaGetWebProperties: Get GA Web Property data

Description

Gets the web properties available from the user token

Usage

shinygaGetWebProperties(token, accountId = "~all", start = 1, max = 1000)

Arguments

token
Token passed from shinygaGetToken()
accountId
AccountId of webproperty, or all of them with ~all
start
which data point to start from
max
Maximum number to fetch

Value

If token exists, a dataframe of GA web properties.

See Also

Other fetch data functions: MEgetData; getAndMergeGAAccounts; processManagementData; rollupGA; shinygaGetAccounts; shinygaGetAdWords; shinygaGetCustomDataSources; shinygaGetCustomDimensions; shinygaGetCustomMetrics; shinygaGetFilters; shinygaGetGoals; shinygaGetProfiles; shinygaGetSegments; shinygaGetUsers

Examples

Run this code
## Not run: 
# WebProperties <- shinygaGetWebProperties(123456)
# ## End(Not run)

Run the code above in your browser using DataLab